==> simulatorAPMS_1.8.0.tar.gz: simulatorAPMS/man/runAPComplex.Rd <==
\name{runAPComplex}
\alias{runAPComplex}

\title{A function that calls the complex estimation function, apComplex
  on the simulated output from runSimulators}
\description{


  The runAPComplex function takes the simulated AP-MS experimental data
  (represented as an adjacency matrix) and deletes the proteins from
  this matrix that is either not used as a bait nor ever seen as a prey
  in the experiment. After the deletion, the apComplex is called on the
  resulting matrix.
}
\usage{
runAPComplex(errorModel, vBaits)
}

\arguments{
  \item{errorModel}{An adjacency matrix: the rows are indexed
    by the baits and the columns are indexed by all the proteins found
    in the organism or cell under certain conditions}
  \item{vBaits}{A character vector: baits used in the simulated AP-MS experiment}
}
\details{
  This function runs the estimation algorithm apComplex.
  The algorithm accomplishes two things: it makes decision
  on if a directed edge is a True Positive (TP) or False Positive (FP)
  and if a missing directed edge is a True Negative (TN) or False
  Negative; after total reciprocity is decided, apComplex estimates
  the protein complex bi-partite graph matrix.
}
\value{
  The return value errorComplex is the Bi-partite Graph Incidence Matrix
  estimated by apComplex.
}

\author{Tony Chiang }
\examples{
library(simulatorAPMS)
data(TSNMatrix)
data(vBaits)
data(missedProtEX)
sim = runSimulators(TSNMatrix, vBaits, vBaits[2], vBaits[5], 0.0003,
0.1, 0, 0, missedProtEX, 357)
runAPComplex(sim, vBaits)
}

\keyword{datagen}

==> simulatorAPMS_1.22.0.tar.gz: simulatorAPMS/man/runAPComplex.Rd <==
\name{runAPComplex}
\alias{runAPComplex}

\title{A function that calls the complex estimation function, apComplex
  on the simulated output from runSimulators}
\description{


  The runAPComplex function takes the simulated AP-MS experimental data
  (represented as an adjacency matrix) and deletes the proteins from
  this matrix that is either not used as a bait nor ever seen as a prey
  in the experiment. After the deletion, the apComplex is called on the
  resulting matrix.
}
\usage{
runAPComplex(errorModel, vBaits)
}

\arguments{
  \item{errorModel}{An adjacency matrix: the rows are indexed
    by the baits and the columns are indexed by all the proteins found
    in the organism or cell under certain conditions}
  \item{vBaits}{A character vector: baits used in the simulated AP-MS experiment}
}
\details{
  This function runs the estimation algorithm apComplex.
  The algorithm accomplishes two things: it makes decision
  on if a directed edge is a True Positive (TP) or False Positive (FP)
  and if a missing directed edge is a True Negative (TN) or False
  Negative; after total reciprocity is decided, apComplex estimates
  the protein complex bi-partite graph matrix.
}
\value{
  The return value errorComplex is the Bi-partite Graph Incidence Matrix
  estimated by apComplex.
}

\author{Tony Chiang }
\examples{
#data(TSNMatrix)
#data(vBaits)
#data(missedProtEX)
#sim = runSimulators(TSNMatrix, vBaits, vBaits[2], vBaits[5], 0.0003,
#0.1, 0, 0, missedProtEX, 357)
#runAPComplex(sim, vBaits)
}

\keyword{datagen}
